==> org.eclipse.jdt.ui.source_3.27.0.v20220824-0714.jar: org/eclipse/jdt/internal/ui/refactoring/ExtractTempWizard.java <==
/*******************************************************************************
 * Copyright (c) 2000, 2018 IBM Corporation and others.
 *
 * This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License 2.0
 * which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.jdt.internal.ui.refactoring;

import org.eclipse.swt.SWT;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Text;

import org.eclipse.core.runtime.Assert;

import org.eclipse.jface.dialogs.Dialog;
import org.eclipse.jface.dialogs.IDialogSettings;

import org.eclipse.ui.PlatformUI;

import org.eclipse.ltk.core.refactoring.RefactoringStatus;
import org.eclipse.ltk.ui.refactoring.RefactoringWizard;

import org.eclipse.jdt.internal.corext.refactoring.code.ExtractTempRefactoring;

import org.eclipse.jdt.internal.ui.IJavaHelpContextIds;
import org.eclipse.jdt.internal.ui.refactoring.contentassist.ControlContentAssistHelper;
import org.eclipse.jdt.internal.ui.refactoring.contentassist.VariableNamesProcessor;
import org.eclipse.jdt.internal.ui.util.RowLayouter;

public class ExtractTempWizard extends RefactoringWizard {

	/* package */ static final String DIALOG_SETTING_SECTION= "ExtractTempWizard"; //$NON-NLS-1$

	public ExtractTempWizard(ExtractTempRefactoring ref) {
		super(ref, DIALOG_BASED_USER_INTERFACE | PREVIEW_EXPAND_FIRST_NODE);
		setDefaultPageTitle(RefactoringMessages.ExtractTempWizard_defaultPageTitle);
	}

	/* non java-doc
	 * @see RefactoringWizard#addUserInputPages
	 */
	@Override
	protected void addUserInputPages(){
		addPage(new ExtractTempInputPage(getExtractTempRefactoring().guessTempNames()));
	}

	private ExtractTempRefactoring getExtractTempRefactoring(){
		return (ExtractTempRefactoring)getRefactoring();
	}

	private static class ExtractTempInputPage extends TextInputWizardPage {

		private static final String DECLARE_FINAL= "declareFinal";  //$NON-NLS-1$
		private static final String REPLACE_ALL= "replaceOccurrences";  //$NON-NLS-1$
		private static final String DECLARE_TYPE_VAR= "declarevariableTypeVar"; //$NON-NLS-1$

		private final boolean fInitialValid;
		private static final String DESCRIPTION = RefactoringMessages.ExtractTempInputPage_enter_name;
		private String[] fTempNameProposals;
		private IDialogSettings fSettings;

		public ExtractTempInputPage(String[] tempNameProposals) {
			super(DESCRIPTION, true, tempNameProposals.length == 0 ? "" : tempNameProposals[0]); //$NON-NLS-1$
			Assert.isNotNull(tempNameProposals);
			fTempNameProposals= tempNameProposals;
			fInitialValid= tempNameProposals.length > 0;
		}

		@Override
		public void createControl(Composite parent) {
			loadSettings();
			Composite result= new Composite(parent, SWT.NONE);
			setControl(result);
			GridLayout layout= new GridLayout();
			layout.numColumns= 2;
			layout.verticalSpacing= 8;
			result.setLayout(layout);
			RowLayouter layouter= new RowLayouter(2);

			Label label= new Label(result, SWT.NONE);
			label.setText(RefactoringMessages.ExtractTempInputPage_variable_name);

			Text text= createTextInputField(result);
			text.selectAll();
			text.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
			ControlContentAssistHelper.createTextContentAssistant(text, new VariableNamesProcessor(fTempNameProposals));

			layouter.perform(label, text, 1);

			addReplaceAllCheckbox(result, layouter);
			addDeclareFinalCheckbox(result, layouter);
			addDeclareTypeVarCheckbox(result, layouter);

			validateTextField(text.getText());

			Dialog.applyDialogFont(result);
			PlatformUI.getWorkbench().getHelpSystem().setHelp(getControl(), IJavaHelpContextIds.EXTRACT_TEMP_WIZARD_PAGE);
		}

		private void loadSettings() {
			fSettings= getDialogSettings().getSection(ExtractTempWizard.DIALOG_SETTING_SECTION);
			if (fSettings == null) {
				fSettings= getDialogSettings().addNewSection(ExtractTempWizard.DIALOG_SETTING_SECTION);
				fSettings.put(DECLARE_FINAL, false);
				fSettings.put(DECLARE_TYPE_VAR, false);
				fSettings.put(REPLACE_ALL, true);
			}
			getExtractTempRefactoring().setDeclareFinal(fSettings.getBoolean(DECLARE_FINAL));
			getExtractTempRefactoring().setDeclareVarType(fSettings.getBoolean(DECLARE_TYPE_VAR));
			getExtractTempRefactoring().setReplaceAllOccurrences(fSettings.getBoolean(REPLACE_ALL));
		}

		private void addReplaceAllCheckbox(Composite result, RowLayouter layouter) {
			String title= RefactoringMessages.ExtractTempInputPage_replace_all;
			boolean defaultValue= getExtractTempRefactoring().replaceAllOccurrences();
			final Button checkBox= createCheckbox(result,  title, defaultValue, layouter);
			getExtractTempRefactoring().setReplaceAllOccurrences(checkBox.getSelection());
			checkBox.addSelectionListener(new SelectionAdapter(){
				@Override
				public void widgetSelected(SelectionEvent e) {
					fSettings.put(REPLACE_ALL, checkBox.getSelection());
					getExtractTempRefactoring().setReplaceAllOccurrences(checkBox.getSelection());
				}
			});
		}

		private void addDeclareFinalCheckbox(Composite result, RowLayouter layouter) {
			String title= RefactoringMessages.ExtractTempInputPage_declare_final;
			boolean defaultValue= getExtractTempRefactoring().declareFinal();
			final Button checkBox= createCheckbox(result,  title, defaultValue, layouter);
			getExtractTempRefactoring().setDeclareFinal(checkBox.getSelection());
			checkBox.addSelectionListener(new SelectionAdapter(){
				@Override
				public void widgetSelected(SelectionEvent e) {
					fSettings.put(DECLARE_FINAL, checkBox.getSelection());
					getExtractTempRefactoring().setDeclareFinal(checkBox.getSelection());
				}
			});
		}

		private void addDeclareTypeVarCheckbox(Composite result, RowLayouter layouter) {
			if (getExtractTempRefactoring().isVarTypeAllowed()) {
				String title= RefactoringMessages.ExtractTempInputPage_declare_type_var;
				boolean defaultValue= getExtractTempRefactoring().declareVarType();
				final Button checkBox= createCheckbox(result,  title, defaultValue, layouter);
				getExtractTempRefactoring().setDeclareVarType(checkBox.getSelection());
				checkBox.addSelectionListener(new SelectionAdapter(){
					@Override
					public void widgetSelected(SelectionEvent e) {
						fSettings.put(DECLARE_TYPE_VAR, checkBox.getSelection());
						getExtractTempRefactoring().setDeclareVarType(checkBox.getSelection());
					}
				});
			}
		}

		/*
		 * @see org.eclipse.jdt.internal.ui.refactoring.TextInputWizardPage#textModified(java.lang.String)
		 */
		@Override
		protected void textModified(String text) {
			getExtractTempRefactoring().setTempName(text);
			super.textModified(text);
		}


		/*
		 * @see org.eclipse.jdt.internal.ui.refactoring.TextInputWizardPage#validateTextField(String)
		 */
		@Override
		protected RefactoringStatus validateTextField(String text) {
			return getExtractTempRefactoring().checkTempName(text);
		}

		private ExtractTempRefactoring getExtractTempRefactoring(){
			return (ExtractTempRefactoring)getRefactoring();
		}

		private static Button createCheckbox(Composite parent, String title, boolean value, RowLayouter layouter){
			Button checkBox= new Button(parent, SWT.CHECK);
			checkBox.setText(title);
			checkBox.setSelection(value);
			layouter.perform(checkBox);
			return checkBox;
		}

		/*
		 * @see org.eclipse.jdt.internal.ui.refactoring.TextInputWizardPage#isInitialInputValid()
		 */
		@Override
		protected boolean isInitialInputValid() {
			return fInitialValid;
		}
	}
}

==> org.eclipse.jdt.ui.source_3.32.100.v20240524-2038.jar: org/eclipse/jdt/internal/ui/refactoring/ExtractTempWizard.java <==
/*******************************************************************************
 * Copyright (c) 2000, 2023 IBM Corporation and others.
 *
 * This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License 2.0
 * which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *     Taiming Wang <3120205503@bit.edu.cn> - [extract local] Context-based Automated Name Recommendation For The Extract Local Variable Refactoring. - https://github.com/eclipse-jdt/eclipse.jdt.ui/issues/655
 *     Taiming Wang <3120205503@bit.edu.cn> - [extract local] Extract Similar Expression in All Methods If End-Users Want. - https://github.com/eclipse-jdt/eclipse.jdt.ui/issues/785
 *******************************************************************************/
package org.eclipse.jdt.internal.ui.refactoring;

import org.eclipse.swt.SWT;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Text;

import org.eclipse.core.runtime.Assert;

import org.eclipse.jface.dialogs.Dialog;
import org.eclipse.jface.dialogs.IDialogSettings;

import org.eclipse.ui.PlatformUI;

import org.eclipse.ltk.core.refactoring.RefactoringStatus;
import org.eclipse.ltk.ui.refactoring.RefactoringWizard;

import org.eclipse.jdt.internal.corext.refactoring.code.ExtractTempRefactoring;

import org.eclipse.jdt.internal.ui.IJavaHelpContextIds;
import org.eclipse.jdt.internal.ui.refactoring.contentassist.ControlContentAssistHelper;
import org.eclipse.jdt.internal.ui.refactoring.contentassist.VariableNamesProcessor;
import org.eclipse.jdt.internal.ui.util.RowLayouter;

public class ExtractTempWizard extends RefactoringWizard {

	/* package */ static final String DIALOG_SETTING_SECTION= "ExtractTempWizard"; //$NON-NLS-1$
	private static Button checkBoxForAllInFile= null;

	public ExtractTempWizard(ExtractTempRefactoring ref) {
		super(ref, DIALOG_BASED_USER_INTERFACE | PREVIEW_EXPAND_FIRST_NODE);
		setDefaultPageTitle(RefactoringMessages.ExtractTempWizard_defaultPageTitle);
	}

	/* non java-doc
	 * @see RefactoringWizard#addUserInputPages
	 */
	@Override
	protected void addUserInputPages(){
		addPage(new ExtractTempInputPage(getExtractTempRefactoring().guessTempNamesWithContext()));
	}

	private ExtractTempRefactoring getExtractTempRefactoring(){
		return (ExtractTempRefactoring)getRefactoring();
	}

	private static class ExtractTempInputPage extends TextInputWizardPage {

		private static final String DECLARE_FINAL= "declareFinal";  //$NON-NLS-1$
		private static final String REPLACE_ALL= "replaceOccurrences";  //$NON-NLS-1$
		private static final String REPLACE_ALL_IN_FILE= "replaceOccurrencesInThisFile";  //$NON-NLS-1$
		private static final String DECLARE_TYPE_VAR= "declarevariableTypeVar"; //$NON-NLS-1$

		private final boolean fInitialValid;
		private static final String DESCRIPTION = RefactoringMessages.ExtractTempInputPage_enter_name;
		private String[] fTempNameProposals;
		private IDialogSettings fSettings;

		public ExtractTempInputPage(String[] tempNameProposals) {
			super(DESCRIPTION, true, tempNameProposals.length == 0 ? "" : tempNameProposals[0]); //$NON-NLS-1$
			Assert.isNotNull(tempNameProposals);
			fTempNameProposals= tempNameProposals;
			fInitialValid= tempNameProposals.length > 0;
		}

		@Override
		public void createControl(Composite parent) {
			loadSettings();
			Composite result= new Composite(parent, SWT.NONE);
			setControl(result);
			GridLayout layout= new GridLayout();
			layout.numColumns= 2;
			layout.verticalSpacing= 8;
			result.setLayout(layout);
			RowLayouter layouter= new RowLayouter(2);

			Label label= new Label(result, SWT.NONE);
			label.setText(RefactoringMessages.ExtractTempInputPage_variable_name);

			Text text= createTextInputField(result);
			text.selectAll();
			text.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
			ControlContentAssistHelper.createTextContentAssistant(text, new VariableNamesProcessor(fTempNameProposals));

			layouter.perform(label, text, 1);

			addReplaceAllCheckbox(result, layouter);
			addReplaceAllInFileCheckbox(result, layouter);
			addDeclareFinalCheckbox(result, layouter);
			addDeclareTypeVarCheckbox(result, layouter);




			validateTextField(text.getText());

			Dialog.applyDialogFont(result);
			PlatformUI.getWorkbench().getHelpSystem().setHelp(getControl(), IJavaHelpContextIds.EXTRACT_TEMP_WIZARD_PAGE);
		}

		private void loadSettings() {
			fSettings= getDialogSettings().getSection(ExtractTempWizard.DIALOG_SETTING_SECTION);
			if (fSettings == null) {
				fSettings= getDialogSettings().addNewSection(ExtractTempWizard.DIALOG_SETTING_SECTION);
				fSettings.put(DECLARE_FINAL, false);
				fSettings.put(DECLARE_TYPE_VAR, false);
				fSettings.put(REPLACE_ALL, true);
				fSettings.put(REPLACE_ALL_IN_FILE, false);
			}
			getExtractTempRefactoring().setDeclareFinal(fSettings.getBoolean(DECLARE_FINAL));
			getExtractTempRefactoring().setDeclareVarType(fSettings.getBoolean(DECLARE_TYPE_VAR));
			getExtractTempRefactoring().setReplaceAllOccurrences(fSettings.getBoolean(REPLACE_ALL));
			getExtractTempRefactoring().setReplaceAllOccurrencesInThisFile(fSettings.getBoolean(REPLACE_ALL_IN_FILE));
		}

		private void addReplaceAllCheckbox(Composite result, RowLayouter layouter) {
			String title= RefactoringMessages.ExtractTempInputPage_replace_all;
			boolean defaultValue= getExtractTempRefactoring().replaceAllOccurrences();
			final Button checkBox= createCheckbox(result, title, defaultValue, layouter);
			getExtractTempRefactoring().setReplaceAllOccurrences(checkBox.getSelection());
			checkBox.addSelectionListener(new SelectionAdapter() {
				@Override
				public void widgetSelected(SelectionEvent e) {
					fSettings.put(REPLACE_ALL, checkBox.getSelection());
					getExtractTempRefactoring().setReplaceAllOccurrences(checkBox.getSelection());
					if (checkBox.getSelection()) {
						checkBoxForAllInFile.setEnabled(true);
					} else {
						checkBoxForAllInFile.setEnabled(false);
						checkBoxForAllInFile.setSelection(false);
						fSettings.put(REPLACE_ALL_IN_FILE, checkBoxForAllInFile.getSelection());
						getExtractTempRefactoring().setReplaceAllOccurrencesInThisFile(checkBoxForAllInFile.getSelection());
					}
				}
			});
		}

		private void addReplaceAllInFileCheckbox(Composite result, RowLayouter layouter) {
			String title= RefactoringMessages.ExtractTempInputPage_replace_all_in_file;
			boolean defaultValue= false;
			checkBoxForAllInFile= createCheckboxIndented(result, title, defaultValue, layouter);
			getExtractTempRefactoring().setReplaceAllOccurrencesInThisFile(checkBoxForAllInFile.getSelection());
			checkBoxForAllInFile.setEnabled(getExtractTempRefactoring().replaceAllOccurrences());
			checkBoxForAllInFile.addSelectionListener(new SelectionAdapter() {
				@Override
				public void widgetSelected(SelectionEvent e) {
					fSettings.put(REPLACE_ALL_IN_FILE, checkBoxForAllInFile.getSelection());
					getExtractTempRefactoring().setReplaceAllOccurrencesInThisFile(checkBoxForAllInFile.getSelection());
				}
			});
		}


		private void addDeclareFinalCheckbox(Composite result, RowLayouter layouter) {
			String title= RefactoringMessages.ExtractTempInputPage_declare_final;
			boolean defaultValue= getExtractTempRefactoring().declareFinal();
			final Button checkBox= createCheckbox(result, title, defaultValue, layouter);
			getExtractTempRefactoring().setDeclareFinal(checkBox.getSelection());
			checkBox.addSelectionListener(new SelectionAdapter() {
				@Override
				public void widgetSelected(SelectionEvent e) {
					fSettings.put(DECLARE_FINAL, checkBox.getSelection());
					getExtractTempRefactoring().setDeclareFinal(checkBox.getSelection());
				}
			});
		}

		private void addDeclareTypeVarCheckbox(Composite result, RowLayouter layouter) {
			if (getExtractTempRefactoring().isVarTypeAllowed()) {
				String title= RefactoringMessages.ExtractTempInputPage_declare_type_var;
				boolean defaultValue= getExtractTempRefactoring().declareVarType();
				final Button checkBox= createCheckbox(result, title, defaultValue, layouter);
				getExtractTempRefactoring().setDeclareVarType(checkBox.getSelection());
				checkBox.addSelectionListener(new SelectionAdapter() {
					@Override
					public void widgetSelected(SelectionEvent e) {
						fSettings.put(DECLARE_TYPE_VAR, checkBox.getSelection());
						getExtractTempRefactoring().setDeclareVarType(checkBox.getSelection());
					}
				});
			}
		}

		/*
		 * @see org.eclipse.jdt.internal.ui.refactoring.TextInputWizardPage#textModified(java.lang.String)
		 */
		@Override
		protected void textModified(String text) {
			getExtractTempRefactoring().setTempName(text);
			super.textModified(text);
		}


		/*
		 * @see org.eclipse.jdt.internal.ui.refactoring.TextInputWizardPage#validateTextField(String)
		 */
		@Override
		protected RefactoringStatus validateTextField(String text) {
			return getExtractTempRefactoring().checkTempName(text);
		}

		private ExtractTempRefactoring getExtractTempRefactoring(){
			return (ExtractTempRefactoring)getRefactoring();
		}

		private static Button createCheckbox(Composite parent, String title, boolean value, RowLayouter layouter){
			Button checkBox= new Button(parent, SWT.CHECK);
			checkBox.setText(title);
			checkBox.setSelection(value);
			layouter.perform(checkBox);
			return checkBox;
		}

		private static Button createCheckboxIndented(Composite parent, String title, boolean value, RowLayouter layouter){
			Button checkBox= new Button(parent, SWT.CHECK);
			GridData gd= new GridData();
			gd.horizontalIndent= 20;
			checkBox.setLayoutData(gd);
			checkBox.setText(title);
			checkBox.setSelection(value);
			layouter.perform(checkBox);
			return checkBox;
		}

		/*
		 * @see org.eclipse.jdt.internal.ui.refactoring.TextInputWizardPage#isInitialInputValid()
		 */
		@Override
		protected boolean isInitialInputValid() {
			return fInitialValid;
		}
	}
}
